import { Component, ViewEncapsulation, HostBinding, Input, Inject, NgModule } from '@angular/core';
import { coerceBooleanProperty } from '@angular/cdk/coercion';
import { CommonModule } from '@angular/common';
import * as ManualModePrism from 'prismjs';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/highlighter/highlighter.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** Perform code hilighting by processing an input text to be rendered into an angular template
 * Using prism as tokenizer @see {https://github.com/PrismJS/prism} */
class PrismHighlighter {
    constructor() {
        this.disabled = false;
    }
    /**
     * Applies the proper classes to the host <pre> element
     * @return {?}
     */
    get clazz() {
        return `wm-prism${this.disabled ? '' : ' language-none'}`;
    }
    /**
     * Disables the highlighting
     * @param {?} value
     * @return {?}
     */
    set disableHighlight(value) { this.disabled = coerceBooleanProperty(value); }
}
PrismHighlighter.decorators = [
    { type: Component, args: [{
                selector: 'pre[wm-prism]',
                template: "\n<code *ngIf=\"!disabled; else transclude\" [language]=\"language\" [wm-prism]=\"source\"></code>\n<ng-template #transclude>\n  <ng-content></ng-content>\n</ng-template>",
                encapsulation: ViewEncapsulation.None,
                styles: [""]
            }] }
];
PrismHighlighter.propDecorators = {
    clazz: [{ type: HostBinding, args: ['class',] }],
    disableHighlight: [{ type: Input, args: ['disabled',] }],
    language: [{ type: Input }],
    source: [{ type: Input, args: ['wm-prism',] }]
};
if (false) {
    /** @type {?} */
    PrismHighlighter.prototype.disabled;
    /**
     * Selects the language
     * @type {?}
     */
    PrismHighlighter.prototype.language;
    /**
     * Parses the source text
     * @type {?}
     */
    PrismHighlighter.prototype.source;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/tokenizer/tokenizer.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PrismTokenizer {
    /**
     * @param {?} prism
     */
    constructor(prism) {
        this.prism = prism;
    }
    /**
     * Selects the most appropriate grammar according to the language
     * @param {?} language
     * @return {?}
     */
    set language(language) {
        this.grammar = !!language ? this.prism.languages[language] : undefined;
    }
    /**
     * Tokenizes the input string or pass along the already tokenized array
     * @param {?} source
     * @return {?}
     */
    set source(source) {
        this.tokens = typeof (source) === 'string' ? this.tokenize(source) : source;
    }
    /**
     * Helper for rendering strings
     * @param {?} token
     * @return {?}
     */
    isString(token) { return typeof (token) === 'string'; }
    /**
     * Helper for rendering tokens
     * @param {?} token
     * @return {?}
     */
    tokenClass(token) {
        // Returns the basic token class + type and appends the aliases, if any 
        return token ? ('token ' + (token.type || '') + this.tokenAliases(token)) : '';
    }
    /**
     * @private
     * @param {?} token
     * @return {?}
     */
    tokenAliases(token) {
        // Skips when no aliases
        if (!token.alias) {
            return '';
        }
        // Appends the multiple aliases
        if (token.alias instanceof Array) {
            return token.alias.reduce((/**
             * @param {?} c
             * @param {?} alias
             * @return {?}
             */
            (c, alias) => c + ' ' + alias), '');
        }
        // Appends the single alias
        return ' ' + token.alias;
    }
    /**
     * @private
     * @param {?} source
     * @return {?}
     */
    tokenize(source) {
        // Skips invalid source
        if (!source) {
            return [''];
        }
        // Returns the full text as a single token when no grammar is defined
        if (!this.grammar) {
            return [source];
        }
        // Tokenize the source code according to the selected grammar
        return this.prism.tokenize(source, this.grammar);
    }
}
PrismTokenizer.decorators = [
    { type: Component, args: [{
                selector: ':not(pre)[wm-prism]',
                template: "<!-- Loops on tokens -->\n<ng-container *ngFor=\"let token of tokens\">\n\n  <!-- Renders plain strings as text nodes -->\n  <ng-container *ngIf=\"isString(token); else spanToken\">{{ token }}</ng-container>\n\n  <!-- Spans the token recurring down the tree with the proper styling otherwise -->\n  <ng-template #spanToken>\n    <span [class]=\"tokenClass(token)\" [wm-prism]=\"token.content\"></span>\n  </ng-template>\n\n</ng-container>\n"
            }] }
];
/** @nocollapse */
PrismTokenizer.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: ['prism',] }] }
];
PrismTokenizer.propDecorators = {
    language: [{ type: Input }],
    source: [{ type: Input, args: ['wm-prism',] }]
};
if (false) {
    /** @type {?} */
    PrismTokenizer.prototype.tokens;
    /**
     * @type {?}
     * @private
     */
    PrismTokenizer.prototype.grammar;
    /**
     * @type {?}
     * @private
     */
    PrismTokenizer.prototype.prism;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/prism-manual-mode.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Forces prism to run in manual mode
((/**
 * @param {?} window
 * @return {?}
 */
function (window) {
    window.Prism = (window.Prism || {});
    window.Prism.manual = true;
})(window || {}));

/**
 * @fileoverview added by tsickle
 * Generated from: lib/prism.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0 = ManualModePrism;
class PrismModule {
}
PrismModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    PrismHighlighter,
                    PrismTokenizer
                ],
                exports: [
                    PrismHighlighter,
                    PrismTokenizer
                ],
                providers: [{ provide: 'prism', useValue: ɵ0 }]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: wizdm-prism.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { PrismHighlighter, PrismModule, PrismTokenizer };
//# sourceMappingURL=wizdm-prism.js.map
